import { renderless, api } from '@opentinyvue/vue-renderless/calendar-view/vue';
import { defineComponent, $prefix, props, setup } from '@opentinyvue/vue-common';
import Button from '@opentinyvue/vue-button';
import DatePicker from '@opentinyvue/vue-date-picker';
import SliderButton from '@opentinyvue/vue-slider-button';
import SliderButtonGroup from '@opentinyvue/vue-slider-button-group';
import Tooltip from '@opentinyvue/vue-tooltip';
import { IconCheckedSur, IconPlus, IconChevronLeft, IconChevronRight, IconDayView, IconAgendaView, IconMonthView } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var classes = {
  "theme-blue": "text-color-brand bg-color-brand-hover-subtle border-l-2 border-color-brand",
  "theme-green": "text-color-success bg-color-success-subtler border-l-2 border-color-success",
  "theme-red": "text-color-error bg-color-error-subtler border-l-2 border-color-error",
  "theme-yellow": "text-color-alert bg-color-alert-subtler border-l-2 border-color-alert",
  "theme-purple": "text-color-chart-11 bg-color-chart-11-subtler border-l-2 border-color-chart-11",
  "theme-cyan": "text-color-chart-5 bg-color-chart-5-subtler border-l-2 border-color-chart-5",
  "theme-grey": "text-color-text-placeholder bg-color-none-disabled border-l-2 border-color-text-placeholder",
  "bg-blue": "bg-color-brand-hover-subtle",
  "bg-green": "bg-color-success-subtler",
  "bg-red": "bg-color-error-subtler",
  "bg-yellow": "bg-color-alert-subtler",
  "bg-purple": "bg-color-chart-11-subtler",
  "bg-cyan": "bg-color-chart-5-subtler",
  "bg-grey": "bg-color-none-disabled",
  "bg-white": "bg-color-bg-1",
  "mark-blue": "bg-color-brand",
  "mark-green": "bg-color-success",
  "mark-red": "bg-color-error",
  "mark-yellow": "bg-color-alert",
  "mark-purple": "bg-color-chart-11",
  "mark-cyan": "bg-color-chart-5",
  "mark-grey": "bg-color-none"
};
var __vue2_script = defineComponent({
  name: $prefix + "CalendarView",
  emits: ["update:modelValue", "new-schedule", "selected-date-change", "prev-week-click", "next-week-click", "week-change", "year-change", "month-change", "date-click", "mode-change"],
  components: {
    TinyButton: Button,
    IconCheckedSur: IconCheckedSur(),
    IconPlus: IconPlus(),
    IconChevronLeft: IconChevronLeft(),
    IconChevronRight: IconChevronRight(),
    TinySliderButton: SliderButton,
    TinySliderButtonGroup: SliderButtonGroup,
    TinyDatePicker: DatePicker,
    TinyTooltip: Tooltip
  },
  props: [].concat(props, ["_constants", "modelValue", "showMark", "showNewSchedule", "setDayBgColor", "disabled", "mode", "modes", "year", "month", "dayTimes", "events", "height", "mark-color", "multi-select", "showBackToday", "showTipTime"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api,
      classes,
      extendOptions: {
        modesIcon: {
          timeline: IconDayView(),
          schedule: IconAgendaView(),
          month: IconMonthView()
        }
      }
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "w-full h-auto",
    attrs: {
      "data-tag": "tiny-calendar-view"
    }
  }, [_c("tiny-tooltip", {
    ref: "tooltip",
    attrs: {
      "popper-class": "absolute max-w-[theme(spacing.80)]",
      "effect": "light",
      "placement": "right"
    },
    scopedSlots: _vm._u([{
      key: "content",
      fn: function fn() {
        return [_c("div", {
          staticClass: "p-2 max-h-[80vh] overflow-auto"
        }, [_c("div", {
          staticClass: "px-1.5 mb-1.5 border-l-2 border-color-brand"
        }, [_vm._v(_vm._s(_vm.state.eventTipContent.title))]), _vm.showTipTime ? _c("div", {
          staticClass: "mb-1.5 px-2 text-color-text-placeholder"
        }, [_vm._v(" " + _vm._s(_vm.state.eventTipContent.startDay) + " " + _vm._s(_vm.state.eventTipContent.startTime) + " ~ " + _vm._s(_vm.state.eventTipContent.endDay) + " " + _vm._s(_vm.state.eventTipContent.endTime) + " ")]) : _vm._e(), _c("p", {
          staticClass: "px-2 text-color-icon-primary"
        }, [_vm._v(_vm._s(_vm.state.eventTipContent.content || ""))])])];
      },
      proxy: true
    }])
  }), _c("div", {
    staticClass: "flex justify-around items-center mb-3",
    attrs: {
      "data-tag": "tiny-calendar-view-today"
    }
  }, [_vm.showBackToday ? _c("tiny-button", {
    on: {
      "click": _vm.toToday
    }
  }, [_vm._v(_vm._s(_vm.t("ui.calendarView.backToday")))]) : _vm._e(), _c("tiny-date-picker", {
    class: [_vm.showBackToday ? "ml-5" : "", "shrink-0"],
    attrs: {
      "shape": "filter",
      "type": "month",
      "clearable": false,
      "format": _vm.t("ui.calendarView.dateFormat")
    },
    on: {
      "change": _vm.currentDateChange
    },
    model: {
      value: _vm.state.currentDate,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "currentDate", $$v);
      },
      expression: "state.currentDate"
    }
  }), _c("div", {
    staticClass: "flex-1 mx-5",
    attrs: {
      "data-tag": "tiny-calendar-view-tool"
    }
  }, [_vm._t("tool")], 2), _vm.modes.length ? _c("tiny-slider-button-group", {
    staticClass: "shrink-0",
    attrs: {
      "type": "icon"
    },
    model: {
      value: _vm.state.mode,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "mode", $$v);
      },
      expression: "state.mode"
    }
  }, _vm._l(_vm.modes, function(mode) {
    return _c("tiny-slider-button", {
      key: mode,
      attrs: {
        "label": mode
      }
    }, [_c(_vm.state.modesIcon[mode], {
      tag: "component"
    })], 1);
  }), 1) : _vm._e()], 1), _vm.state.mode === "month" ? _c("div", {
    staticClass: "shadow-sm",
    attrs: {
      "data-tag": "tiny-calendar-view-monthbox"
    }
  }, [_c("div", {
    staticClass: "flex relative justify-around h-10 shadow-sm",
    attrs: {
      "data-tag": "tiny-calendar-view-month"
    }
  }, [_c("div", {
    staticClass: "absolute left-3 top-2.5 cursor-pointer",
    attrs: {
      "data-tag": "tiny-calendar-view-prevmonth"
    },
    on: {
      "click": _vm.goPrevMonth
    }
  }, [_c("icon-chevron-left")], 1), _c("ul", {
    staticClass: "flex justify-around flex-1 h-full",
    attrs: {
      "data-tag": "tiny-calendar-view-monthlist"
    }
  }, _vm._l(_vm.state.weekDays, function(day) {
    return _c("li", {
      key: day,
      staticClass: "leading-10",
      attrs: {
        "data-tag": "tiny-calendar-view-monthitem"
      }
    }, [_c("span", {
      staticClass: "text-sm text-color-text-primary"
    }, [_vm._v(_vm._s(_vm.t("ui.calendarView.weekDays." + day)))])]);
  }), 0), _c("div", {
    staticClass: "absolute right-3 top-2.5 cursor-pointer",
    attrs: {
      "data-tag": "tiny-calendar-view-nextmonth"
    },
    on: {
      "click": _vm.goNextMonth
    }
  }, [_c("icon-chevron-right")], 1)]), _c("div", {
    staticClass: "w-full overflow-hidden",
    attrs: {
      "data-tag": "tiny-calendar-view-calendarbox"
    }
  }, [_c("div", {
    staticClass: "w-full mt-0.5"
  }, _vm._l(_vm.state.calendar, function(item, index) {
    return _c("ul", {
      key: index,
      staticClass: "w-full flex justify-around border-b border-color-bg-2",
      attrs: {
        "data-tag": "tiny-calendar-view-calendarlist"
      }
    }, _vm._l(item, function(day, i) {
      return _c("li", {
        key: i,
        staticClass: "py-0.5 relative h-20 overflow-hidden border-r border-color-bg-2",
        class: _vm.m(i === 0 || i === 6 ? "bg-color-bg-6" : "bg-color-bg-1", day.isLast || day.isNext || day.disabled ? "" : _vm.isSelectedDate(day) ? "bg-color-brand-hover-subtle hover:bg-color-brand-hover-subtle" : "hover:bg-color-brand-hover-subtler", _vm.gcls("bg-" + _vm.getDayBgColor(day))),
        style: {
          "width": "14.2857%"
        },
        attrs: {
          "data-tag": "tiny-calendar-view-calendaritem"
        },
        on: {
          "click": function click($event) {
            return _vm.selectDay(day);
          }
        }
      }, [_vm.multiSelect && _vm.isSelectedDate(day) ? _c("div", {
        staticClass: "absolute top-0 right-0 bg-color-brand h-4 w-4 overflow-hidden rounded-bl-lg",
        attrs: {
          "data-tag": "tiny-calendar-view-multiselect"
        }
      }, [_c("icon-checked-sur", {
        staticClass: "fill-color-brand relative -right-px -top-0.5"
      })], 1) : _vm._e(), _c("div", {
        staticClass: "py-1.5 pl-2",
        class: _vm.m(day.isLast || day.isNext ? "text-color-text-primary opacity-30" : _vm.isToday(day) || _vm.isSelectedDate(day) ? "text-color-brand" : "text-color-text-primary", day.disabled ? "text-color-none-hover" : ""),
        attrs: {
          "data-tag": "tiny-calendar-view-daytag"
        }
      }, [_vm._v(" " + _vm._s(_vm.isToday(day) ? _vm.t("ui.datepicker.today") : day.value) + " ")]), _c("div", {
        staticClass: "overflow-y-auto scrollbar-size-0 w-full",
        staticStyle: {
          "max-height": "calc(100% - 26px)"
        },
        attrs: {
          "data-tag": "tiny-calendar-view-timebox"
        }
      }, _vm._l(_vm.getEventByTime(day, _vm._constants.DAY_START_TIME, _vm._constants.DAY_END_TIME), function(event, idx) {
        return _c("div", {
          key: idx,
          staticClass: "mb-0.5",
          on: {
            "mouseenter": function mouseenter($event) {
              return _vm.handleMouseenter($event, event);
            },
            "mouseleave": function mouseleave($event) {
              return _vm.handleMouseleave($event, event);
            }
          }
        }, [_vm.isStartOrEndDay("start", day.value, _vm._constants.DAY_START_TIME, _vm._constants.DAY_END_TIME, event) ? _c("div", {
          staticClass: "pl-0.5",
          class: [event.dayNumber > 1 ? "pr-0" : "pr-0.5"]
        }, [_c("span", {
          staticClass: "px-1.5 inline-block rounded-sm leading-5 line-clamp-1",
          class: [_vm.gcls("theme-" + event.theme)],
          attrs: {
            "data-tag": "tiny-calendar-view-time"
          }
        }, [_vm._v(" " + _vm._s(event.title) + " ")])]) : _c("div", {
          staticClass: "h-5 leading-5",
          class: [_vm.isStartOrEndDay("end", day.value, _vm._constants.DAY_START_TIME, _vm._constants.DAY_END_TIME, event) ? "mr-0.5" : "mr-0", _vm.gcls("bg-" + event.theme)],
          attrs: {
            "data-tag": "tiny-calendar-view-theme"
          }
        })]);
      }), 0)]);
    }), 0);
  }), 0)])]) : _c("div", {
    staticClass: "shadow-sm",
    attrs: {
      "data-tag": "tiny-calendar-view-not-month"
    }
  }, [_c("div", {
    staticClass: "flex justify-around items-center h-10 shadow-sm"
  }, [_c("div", {
    staticClass: "w-7 shrink-0 text-right cursor-pointer",
    attrs: {
      "data-tag": "tiny-calendar-view-prevweek"
    },
    on: {
      "click": _vm.getPrevWeek
    }
  }, [_c("icon-chevron-left")], 1), _c("ul", {
    staticClass: "flex justify-around flex-1 h-full",
    attrs: {
      "data-tag": "tiny-calendar-view-weekdates"
    }
  }, _vm._l(_vm.state.weekDates, function(date, index) {
    return _c("li", {
      key: date.value,
      staticClass: "leading-10 cursor-pointer",
      attrs: {
        "data-tag": "tiny-calendar-view-weekitem"
      },
      on: {
        "click": function click($event) {
          return _vm.selectDay(date);
        }
      }
    }, [_vm._t("header", function() {
      return [_c("span", {
        staticClass: "relative mr-2.5 text-base",
        class: [_vm.dateIsToday(date.value) || _vm.computedSelectDay(date) ? "text-color-brand" : "text-color-text-primary"]
      }, [_c("span", [_vm._v(_vm._s(date.value.split("-")[2]))]), _vm.isShowMark(date.value) ? _c("span", {
        staticClass: "w-1.5 h-1.5 absolute -bottom-2 rounded-full",
        class: [date.value.split("-")[2] > 9 ? "left-2" : "left-0.5", _vm.gcls("mark-" + _vm.markColor)]
      }) : _vm._e()]), _c("span", {
        staticClass: "text-sm",
        class: [_vm.dateIsToday(date.value) || _vm.computedSelectDay(date) ? "text-color-brand" : "text-color-text-placeholder"]
      }, [_vm._v(_vm._s(_vm.dateIsToday(date.value) ? _vm.t("ui.datepicker.today") : _vm.t("ui.calendarView.weekDays." + index)))])];
    }, {
      "slotScope": {
        date: date.value,
        weekDay: _vm.t("ui.calendarView.weekDays." + index)
      }
    })], 2);
  }), 0), _c("div", {
    staticClass: "w-7 shrink-0 text-left cursor-pointer",
    attrs: {
      "data-tag": "tiny-calendar-view-nextvweek"
    },
    on: {
      "click": _vm.getNextWeek
    }
  }, [_c("icon-chevron-right")], 1)]), _vm.state.mode === "timeline" ? _c("div", {
    staticClass: "w-full h-112 flex overflow-y-auto mt-1",
    style: {
      "height": _vm.height
    },
    attrs: {
      "data-tag": "tiny-calendar-view-timeline"
    }
  }, [_c("div", {
    staticClass: "w-12",
    attrs: {
      "data-tag": "tiny-calendar-view-timelinelist"
    }
  }, [_c("ul", _vm._l(_vm.state.dayTimes, function(item, i) {
    return _c("li", {
      key: item.time,
      staticClass: "h-5 text-center border-b",
      class: [i % 2 === 1 ? "border-color-bg-2" : "border-color-bg-1"],
      attrs: {
        "data-tag": "tiny-calendar-view-timelineitem"
      }
    }, [_c("span", {
      staticClass: "text-sm text-color-text-primary"
    }, [_vm._v(_vm._s(item.text.includes("30") ? "" : item.text))])]);
  }), 0)]), _c("div", {
    staticClass: "flex-1",
    attrs: {
      "data-tag": "tiny-calendar-view-timelinelist"
    }
  }, [_c("ul", {
    staticClass: "w-full flex justify-around"
  }, _vm._l(_vm.state.weekDates, function(date, index) {
    return _c("li", {
      key: date.value,
      staticClass: "relative",
      class: [index === 0 || index === 6 ? "bg-color-bg-6" : ""],
      staticStyle: {
        "width": "calc((100% - 10px) / 7)"
      },
      attrs: {
        "data-tag": "tiny-calendar-view-timelineitem"
      }
    }, [_vm._t("timeline" + (index + 1), function() {
      return [_c("ul", _vm._l(_vm.state.dayTimes, function(item, i) {
        return _c("li", {
          key: date.value + item.time,
          staticClass: "relative h-5 p-0.5 list-none border-b border-color-bg-2",
          class: [i % 2 === 0 ? "border-dashed" : "border-solid"]
        }, _vm._l(_vm.getEventByTime(date.value, item.time, _vm.state.dayTimes[i + 1] && _vm.state.dayTimes[i + 1].time), function(event, idx) {
          return _c("div", {
            key: idx,
            staticClass: "w-11/12 flex items-center px-1.5 absolute top-0 left-0 z-10 leading-normal rounded-sm",
            class: [_vm.gcls("theme-" + (event.theme || _vm.blue))],
            style: {
              "height": event.height + "px",
              "left": event.left + "px",
              "width": "calc(92% - " + event.left + "px)"
            }
          }, [_c("span", [_vm._v(_vm._s(event.title))])]);
        }), 0);
      }), 0)];
    }, {
      "slotScope": {
        date: date.value,
        events: _vm.state.curWeekEvents[date.value]
      }
    })], 2);
  }), 0)])]) : _vm._e(), _vm.state.mode === "schedule" ? _c("div", {
    staticClass: "w-full px-6 pb-4 overflow-y-auto h-112",
    style: {
      "height": _vm.height
    },
    attrs: {
      "data-tag": "tiny-calendar-view-schedule"
    }
  }, [_c("ul", {
    staticClass: "flex w-full",
    attrs: {
      "data-tag": "tiny-calendar-view-schedulelist"
    }
  }, _vm._l(_vm.state.weekDates, function(date, index) {
    return _c("li", {
      key: date.value,
      staticClass: "h-full py-3 px-2",
      staticStyle: {
        "width": "14.28%"
      },
      attrs: {
        "data-tag": "tiny-calendar-view-scheduleitem"
      }
    }, [_vm._t("weekday" + (index + 1), function() {
      return _vm._l(_vm.state.curWeekEvents[date.value] || [], function(event, idx) {
        return _c("div", {
          key: idx,
          staticClass: "py-1.5 h-auto border border-color-border-separator rounded mb-2 shadow-sm",
          attrs: {
            "data-tag": "tiny-calendar-view-curWeek"
          }
        }, [_c("div", {
          staticClass: "px-1.5 mb-1.5 border-l-2 border-color-brand break-all"
        }, [_vm._v(_vm._s(event.title))]), _vm.showTipTime ? _c("div", {
          staticClass: "mb-1.5 px-2 text-color-text-placeholder"
        }, [_vm._v(" " + _vm._s(_vm.getEventShowTime("start", event, date.value)) + " - " + _vm._s(_vm.getEventShowTime("end", event, date.value)) + " ")]) : _vm._e(), _c("p", {
          staticClass: "px-2 text-xs text-color-icon-primary line-clamp-2"
        }, [_vm._v(_vm._s(event.content || ""))])]);
      });
    }, {
      "slotScope": {
        date: date.value,
        events: _vm.state.curWeekEvents[date.value]
      }
    }), _vm.isShowNewSchedule(date.value) ? _c("div", {
      staticClass: "h-8 text-center leading-8 w-full mt-2 border border-color-border-separator rounded cursor-pointer",
      attrs: {
        "data-tag": "tiny-calendar-view-newschedule"
      },
      on: {
        "click": function click($event) {
          return _vm.newSchedule(date.value);
        }
      }
    }, [_c("icon-plus", {
      staticClass: "align-sub fill-color-text-placeholder"
    }), _c("span", {
      staticClass: "ml-1 text-color-text-placeholder"
    }, [_vm._v(_vm._s(_vm.t("ui.calendarView.new")))])], 1) : _vm._e()], 2);
  }), 0)]) : _vm._e()])], 1);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobileFirst as default };
